@@ -444,7 +444,6 @@ func TestValidateRuntime(t *testing.T) {
 			runtime:  "docker",
 			errorMsg: "",
 		},
-
 		{
 			runtime:  "test",
 			errorMsg: fmt.Sprintf("Invalid Container Runtime: test. Valid runtimes are: %v", cruntime.ValidRuntimes()),
@@ -860,3 +859,32 @@ func TestImageMatchesBinaryVersion(t *testing.T) {
 		}
 	}
 }
+
+func TestValidateGPUs(t *testing.T) {
+	tests := []struct {
+		gpus     string
+		drvName  string
+		runtime  string
+		errorMsg string
+	}{
+		{"", "kvm", "containerd", ""},
+		{"all", "docker", "docker", ""},
+		{"nvidia", "docker", "docker", ""},
+		{"all", "docker", "", ""},
+		{"nvidia", "docker", "", ""},
+		{"all", "kvm", "docker", "The gpus flag can only be used with the docker driver and docker container-runtime"},
+		{"nvidia", "docker", "containerd", "The gpus flag can only be used with the docker driver and docker container-runtime"},
+		{"cat", "docker", "docker", `The gpus flag must be passed a value of "nvidia" or "all"`},
+	}
+
+	for _, tc := range tests {
+		gotError := ""
+		got := validateGPUs(tc.gpus, tc.drvName, tc.runtime)
+		if got != nil {
+			gotError = got.Error()
+		}
+		if gotError != tc.errorMsg {
+			t.Errorf("validateGPUs(%s, %s, %s) = %q; want = %q", tc.gpus, tc.drvName, tc.runtime, got, tc.errorMsg)
+		}
+	}
+}
