@@ -54,7 +54,7 @@ function cleanup() {
 		# clear the known_host file (~/.ssh/known_hosts)
 		if test -f /home/${user}/.ssh/known_hosts; then
 			sudo echo "" > /home/${user}/.ssh/known_hosts
-			ssh-keyscan github.com >>~/.ssh/known_hosts
+			ssh-keyscan github.com >> /home/${user}/.ssh/known_hosts
 		fi
 	done
 	# clean docker left overs
