@@ -124,6 +124,7 @@ func GenerateKubeadmYAML(cc config.ClusterConfig, n config.Node, r cruntime.Mana
 		KubeProxyOptions           map[string]string
 		ResolvConfSearchRegression bool
 		KubeletConfigOpts          map[string]string
+		PrependCriSocketUnix       bool
 	}{
 		CertDir:           vmpath.GuestKubernetesCertsDir,
 		ServiceCIDR:       constants.DefaultServiceCIDR,
@@ -169,6 +170,9 @@ func GenerateKubeadmYAML(cc config.ClusterConfig, n config.Node, r cruntime.Mana
 	if version.GTE(semver.MustParse("1.23.0")) {
 		configTmpl = ktmpl.V1Beta3
 	}
+	if version.GTE(semver.MustParse("1.24.0-alpha.2")) {
+		opts.PrependCriSocketUnix = true
+	}
 	klog.Infof("kubeadm options: %+v", opts)
 	b := bytes.Buffer{}
 	if err := configTmpl.Execute(&b, opts); err != nil {
