@@ -21,6 +21,13 @@ package constants
 // ValidKubernetesVersions is a list of Kubernetes versions in order from newest to oldest
 // This is used when outputting Kubernetes versions and to select the latest patch version when unspecified
 var ValidKubernetesVersions = []string{
+	"v1.29.0-alpha.3",
+	"v1.29.0-alpha.2",
+	"v1.29.0-alpha.1",
+	"v1.28.3",
+	"v1.28.2",
+	"v1.28.1",
+	"v1.28.0",
 	"v1.28.0-rc.1",
 	"v1.28.0-rc.0",
 	"v1.28.0-beta.0",
@@ -28,6 +35,9 @@ var ValidKubernetesVersions = []string{
 	"v1.28.0-alpha.3",
 	"v1.28.0-alpha.2",
 	"v1.28.0-alpha.1",
+	"v1.27.7",
+	"v1.27.6",
+	"v1.27.5",
 	"v1.27.4",
 	"v1.27.3",
 	"v1.27.2",
@@ -39,6 +49,9 @@ var ValidKubernetesVersions = []string{
 	"v1.27.0-alpha.3",
 	"v1.27.0-alpha.2",
 	"v1.27.0-alpha.1",
+	"v1.26.10",
+	"v1.26.9",
+	"v1.26.8",
 	"v1.26.7",
 	"v1.26.6",
 	"v1.26.5",
@@ -53,6 +66,9 @@ var ValidKubernetesVersions = []string{
 	"v1.26.0-alpha.3",
 	"v1.26.0-alpha.2",
 	"v1.26.0-alpha.1",
+	"v1.25.15",
+	"v1.25.14",
+	"v1.25.13",
 	"v1.25.12",
 	"v1.25.11",
 	"v1.25.10",
@@ -72,6 +88,7 @@ var ValidKubernetesVersions = []string{
 	"v1.25.0-alpha.3",
 	"v1.25.0-alpha.2",
 	"v1.25.0-alpha.1",
+	"v1.24.17",
 	"v1.24.16",
 	"v1.24.15",
 	"v1.24.14",
