@@ -87,27 +87,25 @@ func TestCacheBinariesForBootstrapper(t *testing.T) {
 	minikubeHome := t.TempDir()
 
 	var tc = []struct {
-		version, clusterBootstrapper string
-		minikubeHome                 string
-		err                          bool
+		version      string
+		minikubeHome string
+		err          bool
 	}{
 		{
-			version:             "v1.16.0",
-			clusterBootstrapper: bootstrapper.Kubeadm,
-			err:                 false,
-			minikubeHome:        minikubeHome,
+			version:      "v1.16.0",
+			err:          false,
+			minikubeHome: minikubeHome,
 		},
 		{
-			version:             "invalid version",
-			clusterBootstrapper: bootstrapper.Kubeadm,
-			err:                 true,
-			minikubeHome:        minikubeHome,
+			version:      "invalid version",
+			err:          true,
+			minikubeHome: minikubeHome,
 		},
 	}
 	for _, test := range tc {
 		t.Run(test.version, func(t *testing.T) {
 			t.Setenv("MINIKUBE_HOME", test.minikubeHome)
-			err := CacheBinariesForBootstrapper(test.version, test.clusterBootstrapper, nil, "")
+			err := CacheBinariesForBootstrapper(test.version, nil, "")
 			if err != nil && !test.err {
 				t.Fatalf("Got unexpected error %v", err)
 			}
@@ -119,8 +117,7 @@ func TestCacheBinariesForBootstrapper(t *testing.T) {
 }
 
 func TestExcludedBinariesNotDownloaded(t *testing.T) {
-	clusterBootstrapper := bootstrapper.Kubeadm
-	binaryList := bootstrapper.GetCachedBinaryList(clusterBootstrapper)
+	binaryList := bootstrapper.GetCachedBinaryList()
 	binaryToExclude := binaryList[0]
 
 	download.DownloadMock = func(src, dst string) error {
@@ -133,7 +130,7 @@ func TestExcludedBinariesNotDownloaded(t *testing.T) {
 	minikubeHome := t.TempDir()
 	t.Setenv("MINIKUBE_HOME", minikubeHome)
 
-	if err := CacheBinariesForBootstrapper("v1.16.0", clusterBootstrapper, []string{binaryToExclude}, ""); err != nil {
+	if err := CacheBinariesForBootstrapper("v1.16.0", []string{binaryToExclude}, ""); err != nil {
 		t.Errorf("Failed to cache binaries: %v", err)
 	}
 }
