@@ -24,7 +24,6 @@ import (
 	"strings"
 	"time"
 
-	"github.com/docker/machine/drivers/virtualbox"
 	"github.com/docker/machine/libmachine"
 	"github.com/docker/machine/libmachine/host"
 	"github.com/docker/machine/libmachine/state"
@@ -74,7 +73,7 @@ func fixHost(api libmachine.API, cc *config.ClusterConfig, n *config.Node) (*hos
 	}
 
 	// Avoid reprovisioning "none" driver because provision.Detect requires SSH
-	if !driver.BareMetal(h.Driver.DriverName()) {
+	if !driver.BareMetal(driverName) {
 		e := engineOptions(*cc)
 		h.HostOptions.EngineOptions.Env = e.Env
 		err = provisionDockerMachine(h)
@@ -91,12 +90,7 @@ func fixHost(api libmachine.API, cc *config.ClusterConfig, n *config.Node) (*hos
 		return h, errors.Wrap(err, "post-start")
 	}
 
-	if driver.BareMetal(h.Driver.DriverName()) {
-		klog.Infof("%s is local, skipping auth/time setup (requires ssh)", driverName)
-		return h, nil
-	}
-
-	return h, ensureSyncedGuestClock(h, driverName)
+	return h, nil
 }
 
 func recreateIfNeeded(api libmachine.API, cc *config.ClusterConfig, n *config.Node, h *host.Host) (*host.Host, error) {
@@ -156,7 +150,7 @@ func recreateIfNeeded(api libmachine.API, cc *config.ClusterConfig, n *config.No
 	return h, nil
 }
 
-// maybeWarnAboutEvalEnv wil warn user if they need to re-eval their docker-env, podman-env
+// maybeWarnAboutEvalEnv will warn user if they need to re-eval their docker-env, podman-env
 // because docker changes the allocated bind ports after restart https://github.com/kubernetes/minikube/issues/6824
 func maybeWarnAboutEvalEnv(drver string, name string) {
 	if !driver.IsKIC(drver) {
@@ -240,15 +234,6 @@ func machineExistsState(s state.State, err error) (bool, error) {
 	return true, err
 }
 
-func machineExistsError(s state.State, err error, drverr error) (bool, error) {
-	_ = s // not used
-	if err == drverr {
-		// if the error matches driver error
-		return false, constants.ErrMachineMissing
-	}
-	return true, err
-}
-
 func machineExistsMessage(s state.State, err error, msg string) (bool, error) {
 	if s == state.None || (err != nil && err.Error() == msg) {
 		// if the error contains the message
@@ -286,11 +271,9 @@ func machineExists(d string, s state.State, err error) (bool, error) {
 	case driver.Parallels:
 		return machineExistsMessage(s, err, "connection is shut down")
 	case driver.VirtualBox:
-		return machineExistsError(s, err, virtualbox.ErrMachineNotExist)
+		return machineExistsMessage(s, err, "machine does not exist")
 	case driver.VMware:
 		return machineExistsState(s, err)
-	case driver.VMwareFusion:
-		return machineExistsState(s, err)
 	case driver.Docker:
 		return machineExistsDocker(s, err)
 	case driver.Mock:
