@@ -106,6 +106,7 @@ func TestFunctional(t *testing.T) {
 			{"ComponentHealth", validateComponentHealth},
 			{"LogsCmd", validateLogsCmd},
 			{"LogsFileCmd", validateLogsFileCmd},
+			{"InvalidService", validateInvalidService},
 		}
 		for _, tc := range tests {
 			tc := tc
@@ -240,7 +241,7 @@ func tagAndLoadImage(ctx context.Context, t *testing.T, profile, taggedImage str
 		t.Fatalf("failed to setup test (tag image) : %v\n%s", err, rr.Output())
 	}
 
-	rr, err = Run(t, exec.CommandContext(ctx, Target(), "-p", profile, "image", "load", "--daemon", taggedImage))
+	rr, err = Run(t, exec.CommandContext(ctx, Target(), "-p", profile, "image", "load", "--daemon", taggedImage, "--alsologtostderr"))
 	if err != nil {
 		t.Fatalf("loading image into minikube from daemon: %v\n%s", err, rr.Output())
 	}
@@ -256,7 +257,7 @@ func runImageList(ctx context.Context, t *testing.T, profile, testName, format,
 	t.Run(testName, func(t *testing.T) {
 		MaybeParallel(t)
 
-		rr, err := Run(t, exec.CommandContext(ctx, Target(), "-p", profile, "image", "ls", "--format", format))
+		rr, err := Run(t, exec.CommandContext(ctx, Target(), "-p", profile, "image", "ls", "--format", format, "--alsologtostderr"))
 		if err != nil {
 			t.Fatalf("listing image with minikube: %v\n%s", err, rr.Output())
 		}
@@ -310,7 +311,7 @@ func validateImageCommands(ctx context.Context, t *testing.T, profile string) {
 		newImage := fmt.Sprintf("localhost/my-image:%s", profile)
 
 		// try to build the new image with minikube
-		rr, err := Run(t, exec.CommandContext(ctx, Target(), "-p", profile, "image", "build", "-t", newImage, filepath.Join(*testdataDir, "build")))
+		rr, err := Run(t, exec.CommandContext(ctx, Target(), "-p", profile, "image", "build", "-t", newImage, filepath.Join(*testdataDir, "build"), "--alsologtostderr"))
 		if err != nil {
 			t.Fatalf("building image with minikube: %v\n%s", err, rr.Output())
 		}
@@ -350,7 +351,7 @@ func validateImageCommands(ctx context.Context, t *testing.T, profile string) {
 
 	// docs: Make sure image loading from Docker daemon works by `minikube image load --daemon`
 	t.Run("ImageLoadDaemon", func(t *testing.T) {
-		rr, err := Run(t, exec.CommandContext(ctx, Target(), "-p", profile, "image", "load", "--daemon", taggedImage))
+		rr, err := Run(t, exec.CommandContext(ctx, Target(), "-p", profile, "image", "load", "--daemon", taggedImage, "--alsologtostderr"))
 		if err != nil {
 			t.Fatalf("loading image into minikube from daemon: %v\n%s", err, rr.Output())
 		}
@@ -360,7 +361,7 @@ func validateImageCommands(ctx context.Context, t *testing.T, profile string) {
 
 	// docs: Try to load image already loaded and make sure `minikube image load --daemon` works
 	t.Run("ImageReloadDaemon", func(t *testing.T) {
-		rr, err := Run(t, exec.CommandContext(ctx, Target(), "-p", profile, "image", "load", "--daemon", taggedImage))
+		rr, err := Run(t, exec.CommandContext(ctx, Target(), "-p", profile, "image", "load", "--daemon", taggedImage, "--alsologtostderr"))
 		if err != nil {
 			t.Fatalf("loading image into minikube from daemon: %v\n%s", err, rr.Output())
 		}
@@ -375,7 +376,7 @@ func validateImageCommands(ctx context.Context, t *testing.T, profile string) {
 
 	// docs: Make sure image saving works by `minikube image load --daemon`
 	t.Run("ImageSaveToFile", func(t *testing.T) {
-		rr, err := Run(t, exec.CommandContext(ctx, Target(), "-p", profile, "image", "save", taggedImage, imagePath))
+		rr, err := Run(t, exec.CommandContext(ctx, Target(), "-p", profile, "image", "save", taggedImage, imagePath, "--alsologtostderr"))
 		if err != nil {
 			t.Fatalf("saving image from minikube to file: %v\n%s", err, rr.Output())
 		}
@@ -387,7 +388,7 @@ func validateImageCommands(ctx context.Context, t *testing.T, profile string) {
 
 	// docs: Make sure image removal works by `minikube image rm`
 	t.Run("ImageRemove", func(t *testing.T) {
-		rr, err := Run(t, exec.CommandContext(ctx, Target(), "-p", profile, "image", "rm", taggedImage))
+		rr, err := Run(t, exec.CommandContext(ctx, Target(), "-p", profile, "image", "rm", taggedImage, "--alsologtostderr"))
 		if err != nil {
 			t.Fatalf("removing image from minikube: %v\n%s", err, rr.Output())
 		}
@@ -404,8 +405,8 @@ func validateImageCommands(ctx context.Context, t *testing.T, profile string) {
 
 	// docs: Make sure image loading from file works by `minikube image load`
 	t.Run("ImageLoadFromFile", func(t *testing.T) {
-		rr, err := Run(t, exec.CommandContext(ctx, Target(), "-p", profile, "image", "load", imagePath))
-		if err != nil || rr.Stderr.String() != "" {
+		rr, err := Run(t, exec.CommandContext(ctx, Target(), "-p", profile, "image", "load", imagePath, "--alsologtostderr"))
+		if err != nil || strings.Contains(rr.Output(), "failed pushing to: functional") {
 			t.Fatalf("loading image into minikube from file: %v\n%s", err, rr.Output())
 		}
 
@@ -419,7 +420,7 @@ func validateImageCommands(ctx context.Context, t *testing.T, profile string) {
 			t.Fatalf("failed to remove image from docker: %v\n%s", err, rr.Output())
 		}
 
-		rr, err = Run(t, exec.CommandContext(ctx, Target(), "-p", profile, "image", "save", "--daemon", taggedImage))
+		rr, err = Run(t, exec.CommandContext(ctx, Target(), "-p", profile, "image", "save", "--daemon", taggedImage, "--alsologtostderr"))
 		if err != nil {
 			t.Fatalf("saving image from minikube to daemon: %v\n%s", err, rr.Output())
 		}
@@ -2308,3 +2309,27 @@ func validateLicenseCmd(ctx context.Context, t *testing.T, _ string) {
 		t.Errorf("expected license file to contain %q, but was not found", expectedString)
 	}
 }
+
+// validateInvalidService makes sure minikube will not start a tunnel for an unavailable service that has no running pods
+func validateInvalidService(ctx context.Context, t *testing.T, profile string) {
+
+	// try to start an invalid service. This service is linked to a pod whose image name is invalid, so this pod will never become running
+	rrApply, err := Run(t, exec.CommandContext(ctx, "kubectl", "--context", profile, "apply", "-f", filepath.Join(*testdataDir, "invalidsvc.yaml")))
+	if err != nil {
+		t.Fatalf("%s failed: %v", rrApply.Command(), err)
+	}
+	defer func() {
+		// Cleanup test configurations in advance of future tests
+		rr, err := Run(t, exec.CommandContext(ctx, "kubectl", "--context", profile, "delete", "-f", filepath.Join(*testdataDir, "invalidsvc.yaml")))
+		if err != nil {
+			t.Fatalf("clean up %s failed: %v", rr.Command(), err)
+		}
+	}()
+	time.Sleep(3 * time.Second)
+
+	// try to expose a service, this action is supposed to fail
+	rrService, err := Run(t, exec.CommandContext(ctx, Target(), "service", "invalid-svc", "-p", profile))
+	if err == nil || rrService.ExitCode == 0 {
+		t.Fatalf("%s should have failed: ", rrService.Command())
+	}
+}
